nsamples-ubmsFit-method: Get number of Posterior Samples Stored in a ubmsFit Model

nsamples,ubmsFit-methodR Documentation

Get number of Posterior Samples Stored in a ubmsFit Model

Description

Get number of Posterior Samples Stored in a ubmsFit Model

Usage

## S4 method for signature 'ubmsFit'
nsamples(object, ...)

Arguments

object

A ubmsFit model

...

Currently ignored

Value

An integer representing the number of posterior samples


ubms documentation built on April 23, 2026, 1:07 a.m.